Module: Mesa
Branch: master
Commit: 79bc245c01940f69cba4d3e256c250e8c027902d
URL:    
http://cgit.freedesktop.org/mesa/mesa/commit/?id=79bc245c01940f69cba4d3e256c250e8c027902d

Author: Chia-I Wu <[email protected]>
Date:   Thu Jul 11 08:02:19 2013 +0800

ilo: reduce PIPE_CAP_MAX_TEXTURE_CUBE_LEVELS to 12

So that there are at most (2^22 * 6) texels, lower than the 2^26 limit.

---

 src/gallium/drivers/ilo/ilo_screen.c |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/src/gallium/drivers/ilo/ilo_screen.c 
b/src/gallium/drivers/ilo/ilo_screen.c
index 1e3d096..75fee90 100644
--- a/src/gallium/drivers/ilo/ilo_screen.c
+++ b/src/gallium/drivers/ilo/ilo_screen.c
@@ -312,13 +312,14 @@ ilo_get_param(struct pipe_screen *screen, enum pipe_cap 
param)
        *
        * For 3D textures, we have to set the maximum number of levels to 9,
        * which has at most 2^24 pixels.  For 2D textures, we set it to 14,
        * which has at most 2^26 pixels.
        */
       return 14;
    case PIPE_CAP_MAX_TEXTURE_3D_LEVELS:
       return 9;
    case PIPE_CAP_MAX_TEXTURE_CUBE_LEVELS:
-      return 14;
+      return 12;
    case PIPE_CAP_TEXTURE_MIRROR_CLAMP:
       return false;
    case PIPE_CAP_BLEND_EQUATION_SEPARATE:
@@ -312,13 +312,14 @@ ilo_get_param(struct pipe_screen *screen, enum pipe_cap 
        * For 3D textures, we have to set the maximum number of levels to 9,
        * which has at most 2^24 pixels.  For 2D textures, we set it to 14,
-       * which has at most 2^26 pixels.
+       * which has at most 2^26 pixels.  And for cube textures, we has to set
+       * it to 12.
        */
       return 14;

_______________________________________________
mesa-commit mailing list
[email protected]
http://lists.freedesktop.org/mailman/listinfo/mesa-commit

Reply via email to